@@ -1374,6 +1374,9 @@ E void FDECL(make_stunned, (long,BOOLEAN_P));
 E void FDECL(make_blinded, (long,BOOLEAN_P));
 E void FDECL(make_sick, (long, const char *, BOOLEAN_P,int));
 E void FDECL(make_vomiting, (long,BOOLEAN_P));
+#ifdef JPEXTENSION
+E void FDECL(make_totter, (long, BOOLEAN_P));
+#endif
 E void FDECL(make_hallucinated, (long,BOOLEAN_P,long));
 E int NDECL(dodrink);
 E int FDECL(dopotion, (struct obj *));
@@ -2090,7 +2093,7 @@ E  const char *FDECL(jcannot, (const char *));
 E  const char *FDECL(jpast, (const char *));
 E  const char *FDECL(joffmsg, (struct obj *, const char **));
 E  const char *FDECL(jonmsg, (struct obj *, const char **));
-E  void NDECL(jtrns_init);
+E  void NDECL(init_jtrns);
 E  int NDECL(dotogglelang);
 E  int NDECL(query_lang_mode);
 E  void FDECL(set_trns_mode, (int));
@@ -2109,19 +2112,39 @@ E  void FDECL(jrndm_replace, (char *));
 E  unsigned char *FDECL(e2sj, (unsigned char *));
 E  unsigned char *FDECL(sj2e, (unsigned char *));
 
-E  char *NDECL(remote_err);
-E  int FDECL(connect_scoreserver, (int));
-E  int FDECL(soc_read, (int, char *, int));
-E  int FDECL(soc_wait, (int));
+E  char *NDECL(soc_err);
+E  int FDECL(soc_write, (int, char *, size_t));
+E  int FDECL(soc_read, (int, char *, size_t));
+E  int FDECL(soc_write_str, (int, char *));
 
-E  void FDECL(set_email, (char *));
-E  void FDECL(set_homeurl, (char *));
+E  int NDECL(connect_scoreserver);
+E  int NDECL(connect_bonesserver);
 
-E  char *NDECL(get_email);
+E  void FDECL(report_score, (char *, char *));
+E  void NDECL(send_bones);
+
+#include <nhbuf.h>
+
+E  NHBUF *NDECL(nh_buf_new);
+E  void   FDECL(nh_buf_delete, (NHBUF *b));
+E  int    FDECL(nh_buf_append, (NHBUF *b, const char *data, size_t));
+E  int    FDECL(nh_buf_sprintf, (NHBUF *b, const char *fmt, ...));
+E  int    FDECL(nh_buf_read, (NHBUF *b, int fd));
+E  int    FDECL(nh_buf_write, (NHBUF *b, int fd));
+E  int    FDECL(nh_buf_search, (NHBUF *b, const char *data));	
+E  NHBUF *FDECL(nh_buf_subbuf, (NHBUF *b, int pos1, size_t));
+
+E  void  FDECL(set_homeurl, (char *));
 E  char *NDECL(get_homeurl);
 
+E  void  FDECL(set_proxy, (char *));
+E  char *NDECL(get_proxy);
+E  char *NDECL(get_proxy_host);
+E  int	 NDECL(get_proxy_port);
+
+E  void	NDECL(GTK_init_nhwindows2);
+
 #undef E
 
 #endif /* EXTERN_H */
 
-
