@@ -1,6 +1,6 @@
 /*
 **
-**	$Id: jlib.c,v 1.4 1996/07/17 06:03:45 issei Exp issei $
+**	$Id: jlib.c,v 1.1.3.1 1999/11/17 06:35:05 issei Exp issei $
 **
 */
 
@@ -592,9 +592,9 @@ split_japanese( str, str1, str2, pos )
 	str[i-j] == '}'))
       --j;
     else if(j>1 &&
-	    (!strncmp(str+i-j, "", 2)) ||
-	    (!strncmp(str+i-j, "", 2)) ||
-	    (!strncmp(str+i-j, "", 2)))
+	    ((!strncmp(str+i-j, "", 2)) ||
+	     (!strncmp(str+i-j, "", 2)) ||
+	     (!strncmp(str+i-j, "", 2))))
       j-=2;
     else
       break;
