@@ -205,7 +205,7 @@ int rx, ry, *resp;
 		      (ttmp && ttmp->ttyp == STATUE_TRAP) ?
 			"extraordinary" : "excellent");*/
 		pline("ĦȤƤ%s%sʤ",
-		      The(mons[otmp->corpsenm].mname),
+		      jtrns_mon(The(mons[otmp->corpsenm].mname), -1),
 		      (ttmp && ttmp->ttyp == STATUE_TRAP) ?
 			"Ū" : "ưŪ");
 	    }
@@ -312,7 +312,7 @@ use_stethoscope(obj)
 	}
 
 	if (!its_dead(rx, ry, &res))
-/*JP	    You("hear nothing special."); 	/* not You_hear()  */
+/*JP	    You("hear nothing special.");*/ 	/* not You_hear()  */
 	    pline("̤˲ʹʤ");
 	return res;
 }
@@ -1995,9 +1995,11 @@ struct obj *obj;
 			if (bigmonst(mtmp->data)) {
 				Strcpy(buf, mon_nam(mtmp));
 				wrapped_what = buf;
-			} else if (proficient)
+			} else{ if (proficient){
 				if (attack(mtmp)) return(1);
 				else pline(msg_snap);
+				}
+			}
 		}
 		if (!wrapped_what) {
 			if (IS_FURNITURE(levl[rx][ry].typ))
@@ -2103,8 +2105,9 @@ struct obj *obj;
 		} else {
 /*JP			You("flick your bullwhip towards %s.", mon_nam(mtmp));*/
 			You("%s˸äܤǤä", mon_nam(mtmp));
-			if (proficient)
+			if (proficient){
 				if (attack(mtmp)) return(1);
+			}
 			else
 				pline(msg_snap);
 		}
