@@ -36,7 +36,7 @@ ballfall()
 /*JP		pline_The("iron ball falls on your %s.",*/
 		pline("ŴϤʤ%sξ",
 			body_part(HEAD));
-		if (uarmh)
+		if (uarmh){
 		    if(is_metallic(uarmh)) {
 /*JP			pline("Fortunately, you are wearing a hard helmet.");*/
 			pline("ˤ⡤ʤϸǤȤˤĤƤ");
@@ -44,6 +44,7 @@ ballfall()
 		    } else if (flags.verbose)
 /*JP			Your("%s does not protect you.", xname(uarmh));*/
 			Your("%sϤʤ줭ʤä", xname(uarmh));
+		}
 /*JP		losehp(dmg, "Crunched in the head by an iron ball",
 			NO_KILLER_PREFIX);*/
 		losehp(dmg, "ŴƬǤä",
