@@ -11,7 +11,7 @@
 
 #include "hack.h"
 #include "func_tab.h"
-/* #define DEBUG	/* uncomment for debugging */
+/* #define DEBUG	*//* uncomment for debugging */
 
 /*
  * Some systems may have getchar() return EOF for various reasons, and
@@ -1429,6 +1429,41 @@ register char *cmd;
 	boolean do_walk, do_rush, prefix_seen, bad_command,
 		firsttime = (cmd == 0);
 
+#ifdef NEWBIE
+	if(flags.newbie){
+	    if(!(moves % 256)){
+		if(!newbie.search){
+		    pline("ҥ: 's'̩ϩȯǤ롥");
+		    newbie.search = 1;
+		}
+		else if(!newbie.pickup){
+		    pline("ҥ: ','ϩƤʪΤ򽦤ȤǤ롥");
+		    newbie.pickup = 1;
+		}
+		else if(!newbie.open){
+		    pline("ҥ: 'o'򳫤뤳ȤǤ롥");
+		    newbie.open = 1;
+		}
+		else if(!newbie.down){
+		    pline("ҥ: γعԤˤ'>'");
+		    newbie.down = 1;
+		}
+		else if(!newbie.pray){
+		    pline("ҥ: ԥΤȤ'M-p'ǵȽ뤳Ȥ롥");
+		    newbie.pray = 1;
+		}
+		else if(!newbie.offer && newbie.found_altar && newbie.found_altar + 256 < moves){
+		    pline("ҥ: Ť'M-o'Τ򤷤褦Ȥ뤫⡥");
+		    newbie.offer = 1;
+		}
+		else if(!newbie.loot && newbie.found_chest  && newbie.found_chest + 256 < moves){
+		    pline("ҥ: Ȣ'M-l'ȤνФ򤹤뤳ȤǤ롥");
+		    newbie.loot = 1;
+		}
+	    }
+	}
+#endif
+
 	if (firsttime) {
 		flags.nopick = 0;
 		cmd = parse();
@@ -1614,6 +1649,11 @@ char sym;
 	u.dx = xdir[dp-sdp];
 	u.dy = ydir[dp-sdp];
 	u.dz = zdir[dp-sdp];
+#ifdef JPEXTENSION
+	if(Totter){	/* mirror move */
+	    u.dx = -u.dx;
+	}
+#endif
 	if (u.dx && u.dy && u.umonnum == PM_GRID_BUG) {
 		u.dx = u.dy = 0;
 		return 0;
