@@ -680,6 +680,9 @@ dodown()
 		    (u.ux == sstairs.sx && u.uy == sstairs.sy && !sstairs.up)),
 		ladder_down = (u.ux == xdnladder && u.uy == ydnladder);
 
+#ifdef NEWBIE
+	newbie.down = 1;
+#endif
 	if (Levitation) {
 	    if ((HLevitation & (I_SPECIAL|W_ARTI)) != 0) {
 		/* end controlled levitation */
