@@ -413,7 +413,7 @@ const char *name;
 	if (obj->timed) obj_move_timers(obj, otmp);
 	if (obj->lamplit) obj_move_light_source(obj, otmp);
 
-	/* obfree(obj, otmp);	/* now unnecessary: no pointers on bill */
+	/* obfree(obj, otmp);	*//* now unnecessary: no pointers on bill */
 	dealloc_obj(obj);	/* let us hope nobody else saved a pointer */
 	return otmp;
 }
@@ -527,11 +527,13 @@ register struct obj *obj;
 /*JP		    OBJ_DESCR(objects[otemp.otyp]));*/
 		    jtrns_obj('!', OBJ_DESCR(objects[otemp.otyp])));
 
-	else
+	else{
 /*JP
 	    Sprintf(qbuf, "Call %s:", an(xname(&otemp)));
 */
-	    Sprintf(qbuf, "%s:", an(xname(&otemp)));
+	    Sprintf(qbuf, "%s˲̾Ĥ롩", an(xname(&otemp)));
+
+	}
 	getlin(qbuf, buf);
 	if(!*buf || *buf == '\033')
 		return;
