@@ -726,7 +726,6 @@ dokick()
 	u_wipe_engr(2);
 
 	maploc = &levl[x][y];
-
 	/* The next five tests should stay in    */
 	/* their present order: monsters, pools, */
 	/* objects, non-doors, doors.		 */
@@ -768,6 +767,9 @@ dokick()
 
 	if(!IS_DOOR(maploc->typ)) {
 		if(maploc->typ == SDOOR) {
+#ifdef NEWBIE
+	newbie.try_open = 1000;
+#endif
 		    if(!Levitation && rn2(30) < avrg_attrib) {
 			cvt_sdoor_to_door(maploc);	/* ->typ = DOOR */
 /*JP
@@ -802,6 +804,9 @@ dokick()
 		    } else goto ouch;
 		}
 		if(maploc->typ == SCORR) {
+#ifdef NEWBIE
+	newbie.try_open = 1000;
+#endif
 		    if(!Levitation && rn2(30) < avrg_attrib) {
 /*JP			pline("Crash!  You kick open a secret passage!");*/
 			pline("󡪤ʤ̩ϩ򽳤֤ä");
@@ -1000,6 +1005,9 @@ dumb:
 	/* door is known to be CLOSED or LOCKED */
 	if(rnl(35) < avrg_attrib + (!martial() ? 0 : ACURR(A_DEX))) {
 		boolean shopdoor = *in_rooms(x, y, SHOPBASE) ? TRUE : FALSE;
+#ifdef NEWBIE
+	newbie.try_open = 1000;
+#endif
 		/* break the door */
 		if(maploc->doormask & D_TRAPPED) {
 /*JP		    if (flags.verbose) You("kick the door.");*/
