@@ -1000,11 +1000,12 @@ boolean from_invent;
 			break;
 		case EGG:
 			if (heros_fault) {
-			    if (obj->spe && obj->corpsenm >= LOW_PM)
+			    if (obj->spe && obj->corpsenm >= LOW_PM){
 				if (obj->quan < 5)
 				    change_luck((schar) -(obj->quan));
 				else
 				    change_luck(-5);
+			    }
 			}
 			break;
 	}
