@@ -10,7 +10,7 @@
 */
 
 #include "hack.h"
-/* #define DEBUG	/* uncomment to enable new eat code debugging */
+/* #define DEBUG	*//* uncomment to enable new eat code debugging */
 
 #ifdef DEBUG
 # ifdef WIZARD
@@ -486,7 +486,7 @@ register int pm;
 /*JP
 		    Sprintf(kbuf, "tasting %s meat", mons[pm].mname);
 */
-		    Sprintf(kbuf, "%s򿩤٤", jtrns_mon(mons[pm].mname, -1));
+		    Sprintf(kbuf, "%s򿩤", jtrns_mon(mons[pm].mname, -1));
 		    killer_format = KILLED_BY;
 		    killer = kbuf;
 /*JP
@@ -1423,7 +1423,7 @@ struct obj *otmp;
 		} else
 #endif
 		if (otmp->otyp == EGG && stale_egg(otmp)) {
-/*JP		    pline("Ugh.  Rotten egg.");	/* perhaps others like it */
+/*JP		    pline("Ugh.  Rotten egg.");*//* perhaps others like it */
 		    pline("ä");
 		    make_vomiting(Vomiting+d(10,4), TRUE);
 		} else
@@ -1920,7 +1920,7 @@ register int num;
 #endif
 	u.uhunger += num;
 	if(u.uhunger >= 2000) {
-	    if (!victual.eating || victual.canchoke)
+	    if (!victual.eating || victual.canchoke){
 		if (victual.eating) {
 			choke(victual.piece);
 			reset_eat();
@@ -1929,6 +1929,7 @@ register int num;
 			choke(tin.tin);
 		else
 			choke((struct obj *) 0);
+	    }
 		/* no reset_eat() */
 	} else {
 	    /* Have lesshungry() report when you're nearly full so all eating
@@ -2067,6 +2068,13 @@ boolean incr;
 				afternmv = unfaint;
 				newhs = FAINTED;
 			}
+#ifdef NEWBIE
+			if(!newbie.fainted){
+			     pline("ҥ: ԥΤȤM-pǵȤ⤢롥ꤹա");
+/*			     more();*/
+			     newbie.fainted = 1;
+			}
+#endif
 		} else
 		if(u.uhunger < -(int)(200 + 20*ACURR(A_CON))) {
 			u.uhs = STARVED;
@@ -2116,7 +2124,7 @@ boolean incr;
 			else if (incr &&
 				(Role_is('W') || Role_is('E') || Role_is('V')))
 /*JP			    pline("%s needs food, badly!", pl_character);*/
-			    pline("%sˤϻ޿ɬפ", jtrns_mon(pl_character, flags.female));
+			    pline("޿ɬפ");
 			else
 /*JP			    You((!incr) ? "feel weak now." :
 				  (u.uhunger < 45) ? "feel weak." :
@@ -2127,6 +2135,13 @@ boolean incr;
 			if (incr && occupation &&
 			    (occupation != eatfood && occupation != opentin))
 			    stop_occupation();
+#ifdef NEWBIE
+			if(!newbie.eat){
+			     pline("ҥ: 'e'ǿǤ롣ƤΤ⿩ȤǤ롥");
+/*			     more();*/
+			     newbie.eat = 1;
+			}
+#endif
 			break;
 		}
 		u.uhs = newhs;
