@@ -810,12 +810,13 @@ doengrave()
 		break;
 
 	    case WEAPON_CLASS:
-		if(is_blade(otmp))
+		if(is_blade(otmp)){
 		    if ((int)otmp->spe > -3)
 			type = ENGRAVE;
 		    else
 /*JP			Your("%s too dull for engraving.", aobjnam(otmp,"are"));*/
 			pline("%sϿϤܥܥǡʸĦʤ",xname(otmp));
+		}
 		break;
 
 	    case TOOL_CLASS:
@@ -950,7 +951,7 @@ doengrave()
 		}
 	    }
 
-	    if (c == 'n' || Blind)
+	    if (c == 'n' || Blind){
 
 		if( (oep->engr_type == DUST) || (oep->engr_type == BLOOD) ||
 		    (oep->engr_type == MARK) ) {
@@ -988,6 +989,7 @@ doengrave()
 				You("å񤭤褦Ȥ");
 			    eow = TRUE;
 			}
+	    }
 	}
 
 	eloc = surface(u.ux,u.uy);
