@@ -111,13 +111,14 @@ int drinking;
 	int madepool = 0;
 
 	do_clear_area(u.ux, u.uy, 7, gush, (genericptr_t)&madepool);
-	if (!madepool)
+	if (!madepool){
 	    if (drinking)
 /*JP		Your("thirst is quenched.");*/
 		Your("줿");
 	    else
 /*JP		pline("Water sprays all over you.");*/
 		pline("夷֤ʤˤä");
+	}
 }
 
 STATIC_PTR void
