@@ -1784,6 +1784,10 @@ dolook()
 			align_str(Amask2align(levl[u.ux][u.uy].altarmask
 							    & ~AM_SHRINE)));
 		dfeature = fbuf2;
+#ifdef NEWBIE
+		if(!newbie.found_altar)
+		     newbie.found_altar = moves;
+#endif
 	} else if(u.ux == xupstair && u.uy == yupstair)
 /*JP		dfeature = "stairway up";*/
 		dfeature = "ؤγ";
@@ -1850,6 +1854,10 @@ dolook()
 /*JP
 	    You("%s here %s.", verb, doname(otmp0));
 */
+#ifdef NEWBIE
+	    if(Is_container(otmp0))
+		 newbie.found_chest = moves;
+#endif
 	    pline("%s%s",doname(otmp0),verb);
 	    feel_cockatrice(otmp0, FALSE);
 	} else {
@@ -2209,10 +2217,11 @@ doorganize()	/* inventory organizer by Del Lamb */
 	/* blank out all the letters currently in use in the inventory */
 	/* except those that will be merged with the selected object   */
 	for (otmp = invent; otmp; otmp = otmp->nobj)
-		if (otmp != obj && !mergable(otmp,obj))
+	    if (otmp != obj && !mergable(otmp,obj)){
 			if (otmp->invlet <= 'Z')
 				alphabet[(otmp->invlet) - 'A' + 26] = ' ';
 			else	alphabet[(otmp->invlet) - 'a']	    = ' ';
+	    }
 
 	/* compact the list by removing all the blanks */
 	for (ix = cur = 0; ix <= 52; ix++)
