@@ -72,7 +72,7 @@ lock_action()
 
 	/* if the target is currently unlocked, we're trying to lock it now */
 	if (xlock.door && !(xlock.door->doormask & D_LOCKED))
-/*JP		return actions[0]+2;	/* "locking the door" */
+/*JP		return actions[0]+2;*/	/* "locking the door" */
 		return "˸򤫤";
 	else if (xlock.box && !xlock.box->olocked)
 /*JP		return xlock.box->otyp == CHEST ? actions[1]+2 : actions[2]+2;*/
@@ -94,7 +94,9 @@ STATIC_PTR
 int
 picklock()	/* try to open/close a lock */
 {
-
+#ifdef NEWBIE
+	newbie.unlock = 1;
+#endif
 	if (xlock.box) {
 	    if((xlock.box->ox != u.ux) || (xlock.box->oy != u.uy)) {
 		return((xlock.usedtime = 0));		/* you or it moved */
@@ -584,6 +586,9 @@ doopen()		/* try to open a door */
 	    pline("椫Ϥʤ");
 	    return 0;
 	}
+#ifdef NEWBIE
+	newbie.open = 1;
+#endif
 
 	if(!getdir((char *)0)) return(0);
 
@@ -645,6 +650,15 @@ doopen()		/* try to open a door */
 		  break;
 		default:
 		  pline("ˤϸݤäƤ"); 
+#ifdef NEWBIE 
+		  ++newbie.try_open;
+		  if(newbie.try_open == 10){
+		       pline("ҥ: 򳫤Τ˻Ȥʪõ'a'ǻȤ롥");
+		  }
+		  if(newbie.try_open == 30){
+		       pline("ҥ: ǸμʤȤ'C-d'ǽ֤졪");
+		  }
+#endif
 		  break;
 	    }
 	    if (Blind) feel_location(x,y);
