@@ -894,7 +894,7 @@ register int	mmflags;
 	}
 #ifdef FIGHTER
 	if(ptr == &mons[PM_PLANETARY_FIGHTER]){
-	  static uniq_num = 0;
+	  static int uniq_num = 0;
 	  const char *cn;
 /*Τƽ̾*/
 	  mtmp->female = 1;
