@@ -1467,11 +1467,12 @@ do_stone:
 		hitmsg(mtmp, mattk);
 		if(!night() && mdat == &mons[PM_GREMLIN]) break;
 		if(!mtmp->mcan && !rn2(10)) {
-		    if (flags.soundok)
+		    if (flags.soundok){
 /*JP			if (Blind) You_hear("laughter.");
 			else       pline("%s chuckles.", Monnam(mtmp));*/
 			if (Blind) You_hear("Фʹ");
 			else       pline("%sϥФä", Monnam(mtmp));
+		    }
 		    if (u.umonnum == PM_CLAY_GOLEM) {
 /*JP			pline("Some writing vanishes from your head!");*/
 			pline("ĤʸʤƬä");
