@@ -10,7 +10,7 @@
 */
 
 #include "hack.h"
-/* #define DEBUG	/* uncomment to enable code debugging */
+/* #define DEBUG*/	/* uncomment to enable code debugging */
 
 #ifdef DEBUG
 # ifdef WIZARD
@@ -1323,7 +1323,7 @@ register struct mkroom *croom;
 
 	level.flags.nsinks++;
 }
-#endif /* SINKS /**/
+#endif /* SINKS */
 
 
 static void
