@@ -170,6 +170,11 @@ register boolean special;
 		case PM_ELF:
 		    weapon = ELVEN_SHORT_SWORD;
 		    break;
+#ifdef FIGHTER
+		case PM_FIGHTER:
+		    weapon = SHORT_SWORD;
+		    break;
+#endif
 		case PM_HEALER:
 		    weapon = SCALPEL;
 		    break;
