@@ -128,7 +128,7 @@ int x,y;
 		if (down_gate(x, y) != -1)
 			objgone = ship_object(obj, x, y, FALSE);
 		if (!objgone) {
-/*JP			if (!flooreffects(obj,x,y,"fall")) { /* don't double-dip on damage */
+/*JP			if (!flooreffects(obj,x,y,"fall")) {*/ /* don't double-dip on damage */
 			if (!flooreffects(obj,x,y,"")) { /* don't double-dip on damage */
 			    place_object(obj, x, y);
 			    stackobj(obj);
@@ -350,7 +350,7 @@ m_throw(mon, x, y, dx, dy, range, obj)
 			    dropy(singleobj);
 			} else {
 /*JP			    You("accept %s gift in the spirit in which it was intended.",*/
-			    You("줬ߤäȻפʤ%£ʪȤä",
+			    You("줬ߤäȻפʤ%s£ʪȤä",
 				s_suffix(mon_nam(mon)));
 			    (void)hold_another_object(singleobj,
 /*JP				"You catch, but drop, %s.", xname(singleobj),
