@@ -19,9 +19,11 @@
 #define SCHAR_LIM 127
 
 STATIC_DCL char *FDECL(strprepend,(char *,const char *));
+/*JP
 #ifdef OVL0
 static boolean FDECL(the_unique_obj, (struct obj *obj));
 #endif
+*/
 
 struct Jitem {
 	int item;
@@ -715,7 +717,7 @@ register struct obj *obj;
 	 *  ΤۤǤ롥
          */
 	preprefix[0]='\0';
-	if(tp = strstri(bp,"̾Ť줿")){
+	if((tp = strstri(bp,"̾Ť줿"))!= NULL){
 	  tp += 12;
 	  strncpy(preprefix,bp,tp-bp);
 	  preprefix[tp-bp]='\0';
@@ -885,7 +887,7 @@ plus:
 		}
 		break;
 	case ARMOR_CLASS:
-		if(obj->owornmask & W_ARMOR)
+		if(obj->owornmask & W_ARMOR){
 #if 0 /*JP*/
 			Strcat(bp, (obj == uskin) ? " (embedded in your skin)" :
 				" (being worn)");
@@ -900,6 +902,7 @@ plus:
 			  Strcat(bp, jconj(jonmsg(obj, &dummy), "Ƥ"));
 			  Strcat(bp, ")");
 			}
+		}
 		goto plus;
 	case TOOL_CLASS:		/* temp. hack by GAN 11/18/86 */
 		if(obj->owornmask & W_TOOL) { /* blindfold */
@@ -1802,6 +1805,7 @@ transpose(buf, str)
 /*
 **  ʸ buf Ƭ str
 */
+#if 0
 static 
 char *
 insert(buf, str)
@@ -1810,6 +1814,7 @@ insert(buf, str)
 {
   return substitute(buf, "", str);
 }
+#endif
   
 /*
 **  ʸ buf  str
