@@ -114,7 +114,7 @@ static struct Bool_Opt
 	{"mail", (boolean *)0, FALSE/*JP TRUE*/},
 #endif
 #ifdef NEWBIE
-	{"newbie", &flags.newbie, FALSE},
+	{"newbie", &flags.newbie, TRUE},
 #endif
 #ifdef NEWS
 	{"news", &iflags.news, TRUE},
@@ -140,14 +140,14 @@ static struct Bool_Opt
 	{"preload_tiles", (boolean *)0, FALSE},
 #endif
 #ifdef RADAR
-	{ "radar", &flags.radar, TRUE},
+	{ "radar", &flags.radar, FALSE},
 #endif
 #if defined(MICRO) && !defined(AMIGA)
 	{"rawio", &iflags.rawio, FALSE},
 #else
 	{"rawio", (boolean *)0, FALSE},
 #endif
-#ifdef REPORTSCORE
+#ifdef NH_EXTENSION_REPORT
 	{"report", &flags.reportscore, TRUE},
 #endif
 	{"rest_on_space", &flags.rest_on_space, FALSE},
@@ -178,7 +178,7 @@ static struct Bool_Opt
 	{"timed_delay", (boolean *)0, FALSE},
 #endif
 	{"tombstone",&flags.tombstone, TRUE},
-	{"toptenwin",&flags.toptenwin, FALSE},
+	{"toptenwin",&flags.toptenwin, TRUE/*FALSE */},
 	{"verbose", &flags.verbose, TRUE},
 	{(char *)0, (boolean *)0, FALSE}
 };
@@ -296,8 +296,10 @@ static struct Comp_Opt
 	{ "windowtype", "Ѥ륦ɥƥ,", WINTYPELEN },
 /*JP*/
 	{ "kcode", "üδ,", 4 },
-/*	{ "email", "ʤE-Mailɥ쥹,", 50 },*/
-	{ "home", "ʤΥۡڡURL,", 128 },
+#ifdef	NH_EXTENSION_REPORT
+	{ "homeurl", "ʤΥۡڡURL,", 128 },
+	{ "proxy", "HTTPץ,", 128 },
+#endif
 	{ NULL, NULL }
 };
 
@@ -614,7 +616,7 @@ int i;
 #if defined(MSDOS) && defined(USE_TILES)
 	     || boolopt[i].addr == &iflags.preload_tiles
 #endif
-#ifdef REPORTSCORE	/* JP */
+#ifdef NH_EXTENSION_REPORT
 	     || boolopt[i].addr == &flags.reportscore	
 #endif
 	);
@@ -1206,16 +1208,7 @@ goodfruit:
 	  }
 	  return;
 	}
-/*
-	fullname = "email";
-	if (match_optname(opts, fullname, 3, TRUE)) {
-	    if (negated) 
-		bad_negation(fullname, FALSE);
-	    else if ((op = string_for_env_opt(fullname, opts, FALSE)) != 0)
-		set_email(op);
-	    return;
-	}
-*/
+#ifdef NH_EXTENSION_REPORT
 	fullname = "homeurl";
 	if (match_optname(opts, fullname, 5, TRUE)) {
 	    if (negated) 
@@ -1225,6 +1218,16 @@ goodfruit:
 	    return;
 	}
 
+	fullname = "proxy";
+	if (match_optname(opts, fullname, 5, TRUE)) {
+	    if (negated) 
+		bad_negation(fullname, FALSE);
+	    else if ((op = string_for_env_opt(fullname, opts, FALSE)) != 0)
+		set_proxy(op);
+	    return;
+	}
+#endif
+
 	/* scores:5t[op] 5a[round] o[wn] */
 	if (match_optname(opts, "scores", 4, TRUE)) {
 	    if (negated) {
@@ -1686,8 +1689,11 @@ doset()
 #endif /* VIDEOSHADES */
 	doset_add_menu(tmpwin, "windowtype", windowprocs.name, 0);
 /*JP*/
+#ifdef NH_EXTENSION_REPORT
 /*	doset_add_menu(tmpwin, "email", get_email(), 0);*/
 	doset_add_menu(tmpwin, "homeurl", get_homeurl(), 0);
+	doset_add_menu(tmpwin, "proxy", get_proxy(), 0);
+#endif
 	/* modifiable compounds */
 	doset_add_menu(tmpwin, "disclose",
 		       flags.end_disclose[0] ? flags.end_disclose : "all",
