@@ -171,7 +171,7 @@ lookat(x, y, buf, buf2)
 /*JP	    Strcat(buf, " in water");*/
 	    Strcat(buf, "ˤ");
 	else if (is_lava(x,y))
-/*JP	    Strcat(buf, " in molten lava");	/* [can this ever happen?] */
+/*JP	    Strcat(buf, " in molten lava");*/	/* [can this ever happen?] */
 	    Strcat(buf, "ϴˤ");	/* [can this ever happen?] */
     }
     else if (glyph_is_trap(glyph)) {
@@ -532,9 +532,11 @@ do_look(quick)
 	    x_str = defsyms[i].explanation;
 	    if (sym == (from_screen ? showsyms[i] : defsyms[i].sym) && *x_str) {
 		/* avoid "an air", "a water", or "a floor of a room" */
+#if 0	/*JP*/
 		int article = (i == S_room) ? 2 :		/* 2=>"the" */
 			      !(strcmp(x_str, "air") == 0 ||	/* 1=>"an"  */
 				strcmp(x_str, "water") == 0);	/* 0=>(none)*/
+#endif
 
 		if (!found) {
 		    if (is_cmap_trap(i)) {
@@ -652,14 +654,16 @@ doidtrap()
 			    tt == ROCKTRAP) break;
 		}
 		if (Hallucination) tt = rn1(TRAPNUM-3, 3);
-/*JP		pline("That is %s%s%s.",
+#if 0 /*JP*/
+		pline("That is %s%s%s.",
 		      an(defsyms[trap_to_defsym(tt)].explanation),
 		      !trap->madeby_u ? "" : (tt == WEB) ? " woven" :
 			  /* trap doors & spiked pits can't be made by
 			     player, and should be considered at least
-			     as much "set" as "dug" anyway *
+			     as much "set" as "dug" anyway */
 			  (tt == HOLE || tt == PIT) ? " dug" : " set",
-		      !trap->madeby_u ? "" : " by you");*/
+		      !trap->madeby_u ? "" : " by you");
+#endif
 		pline("%s%s",
 		      !trap->madeby_u ? "" : (tt == WEB) ? "ʤĥä" :
 			  (tt == HOLE || tt == PIT) ? "ʤä" : "ʤųݤ",
