@@ -404,6 +404,9 @@ int what;		/* should be a long */
 	    n = autopick(level.objects[u.ux][u.uy], BY_NEXTHERE, &pick_list);
 	    goto menu_pickup;
 	}
+#ifdef NEWBIE
+	newbie.pickup = 1;
+#endif
 
 	if (flags.menu_style != MENU_TRADITIONAL) {
 	    /* use menus exclusively */
@@ -937,7 +940,7 @@ int *wt_before, *wt_after;
 	return qq;
     }
 
-/*JP    if (!container) Strcpy(where, "here");  /* slightly shorter form */
+/*JP    if (!container) Strcpy(where, "here");*//* slightly shorter form */
     if (!container) Strcpy(where, "ˤ");  /* slightly shorter form */
     if (invent || u.ugold) {
 /*JP
@@ -1254,6 +1257,9 @@ doloot()	/* loot a container on the floor. */
 	register int c = -1;
 	int timepassed = 0;
 
+#ifdef NEWBIE
+	newbie.loot = 1;
+#endif
 	if (check_capacity((char *)0)) {
 		/* "Can't do that while carrying so much stuff." */
 		return 0;
@@ -1279,7 +1285,6 @@ doloot()	/* loot a container on the floor. */
 
 	for(cobj = level.objects[u.ux][u.uy]; cobj; cobj = nobj) {
 		nobj = cobj->nexthere;
-
 		if(Is_container(cobj)) {
 		    char qbuf[QBUFSZ];
 
