@@ -171,7 +171,7 @@ newman()
 		    if (u.uhp <= 0) u.uhp = 1;
 		    if (u.uhpmax <= 0) u.uhpmax = 1;
 		} else {
-/*JP		    Your("new form doesn't seem healthy enough to survive.");
+/*JP		    Your("new form doesn't seem healthy enough to survive.");*/
 		    Your("ѤƤϤʤ褦");
 		    killer_format = KILLED_BY_AN;
 /*JP		    killer="unsuccessful polymorph";*/
@@ -181,7 +181,7 @@ newman()
 	}
 /*JP	polyman("feel like a new %s!",
 		Role_is('E') ? "elf" : flags.female ? "woman" : "man");*/
-	if(saved_sex == flags.female)
+	if(u.umonnum != PM_PLAYERMON || saved_sex == flags.female)
 	  polyman("̤%sȤޤ줫ä褦ʵ",
 	      pl_character[0] == 'E' ? "" : "ʹ");
 	else
@@ -1112,17 +1112,19 @@ int part;
 
 	/* claw attacks are overloaded in mons[]; most humanoids with
 	   such attacks should still reference hands rather than claws */
+#if 0/*JP*/
 	static const char not_claws[] = {
 		S_HUMAN, S_MUMMY, S_ZOMBIE, S_ANGEL,
 		S_NYMPH, S_LEPRECHAUN, S_QUANTMECH, S_VAMPIRE,
 		S_ORC, S_GIANT,		/* quest nemeses */
 		'\0'		/* string terminator; assert( S_xxx != 0 ); */
 	};
+#endif
 
 #if 0 /*JP*/
 /* pawϸȤǭμꡤclawϥ­Τ褦ʤĤᡤ
-/* ɤäܸ줸ּפǤǤ礦
-
+   ɤäܸ줸ּפǤǤ礦
+*/
 	if (part == HAND || part == HANDED) {	/* some special cases */
 	    if (u.usym == S_DOG || u.usym == S_FELINE || u.usym == S_YETI)
 		return part == HAND ? "paw" : "pawed";
