@@ -211,6 +211,24 @@ boolean talk;
 	}
 }
 
+#ifdef	JPEXTENSION
+void
+make_totter(xtime, talk)
+long xtime;	/* nonzero if this is an attempt to turn on hallucination */
+boolean talk;
+{
+	const char *message = 0;
+
+	if (!xtime)
+	    message = "Фˤʤä";
+	else
+	    message = "Ф㤷";
+
+	set_itimeout(&Totter, xtime);
+	pline(message);
+}
+#endif
+
 void
 make_hallucinated(xtime, talk, mask)
 long xtime;	/* nonzero if this is an attempt to turn on hallucination */
@@ -1180,12 +1198,13 @@ register struct obj *obj;
 		break;
 	}
 	/* note: no obfree() */
-	if (obj->dknown)
+	if (obj->dknown){
 	    if (kn)
 		makeknown(obj->otyp);
 	    else if (!objects[obj->otyp].oc_name_known &&
 						!objects[obj->otyp].oc_uname)
 		docall(obj);
+	}
 }
 
 static short
