@@ -1089,6 +1089,9 @@ dosacrifice()
     int value = 0;
     aligntyp altaralign = a_align(u.ux,u.uy);
 
+#ifdef NEWBIE
+    newbie.offer = 1;
+#endif
     if (!on_altar()) {
 /*JP
 	You("are not standing on an altar.");
@@ -1546,7 +1549,7 @@ boolean praying;	/* false means no messages should be given */
 
     if (is_demon(uasmon) && (p_aligntyp != A_CHAOTIC)) {
 	if (praying)
-/*JP	    pline_The("very idea of praying to a %s god is repugnant to you.",*
+/*JP	    pline_The("very idea of praying to a %s god is repugnant to you.",*/
 /*JP		  p_aligntyp ? "lawful" : "neutral");*/
 	    pline("%sο˵򤵤ΤϾＱؤ",
 		p_aligntyp ? "" : "Ω");
@@ -1592,6 +1595,9 @@ dopray()
     /* set up p_type and p_alignment */
     if (!can_pray(TRUE)) return 0;
 
+#ifdef NEWBIE
+    newbie.pray = 1;
+#endif
 #ifdef WIZARD
     if (wizard && p_type >= 0) {
 /*JP	if (yn("Force the gods to be pleased?") == 'y') {*/
@@ -1650,7 +1656,6 @@ prayer_done()		/* M. Stephenson (1.0.3b) */
 	    angrygods(u.ualign.type);
 	return(0);
     }
-
     if (p_type == 0) {
 	if(on_altar() && u.ualign.type != alignment)
 	    (void) water_prayer(FALSE);
