@@ -370,14 +370,14 @@ register int roomno;
 		sanctum = (priest->data == &mons[PM_HIGH_PRIEST] &&
 			   (Is_sanctum(&u.uz) || In_endgame(&u.uz)));
 		can_speak = (priest->mcanmove && !priest->msleep);
-		if (can_speak)
+		if (can_speak){
 /*JP		    pline("%s intones:",
 			  (!Blind ? Monnam(priest) : "A nearby voice"));*/
 		    if(Blind)
 		      pline("᤯ïӾ");
 		    else
 		      pline("%sϱӾ", Monnam(priest));
-
+		}
 
 		msg2 = 0;
 		if(sanctum && Is_sanctum(&u.uz)) {
