@@ -14,7 +14,7 @@
 
 /*  quest-specific pager routines. */
 
-#ifdef _MSC_VER
+#if defined(_MSC_VER) && !defined(WIN32)
 #include "../japanese/emalloc.h"
 #define alloc(s) emalloc(s)
 #endif
@@ -23,7 +23,7 @@
 
 #define QTEXT_FILE	"quest.dat"
 
-/* #define DEBUG	/* uncomment for debugging */
+/* #define DEBUG	*//* uncomment for debugging */
 
 static void FDECL(Fread, (genericptr_t,int,int,dlb *));
 static struct qtmsg * FDECL(construct_qtlist, (long));
@@ -661,6 +661,7 @@ int how;
 	    convert_line();
 	    putstr(datawin, 0, out_line);
 	}
+
 	display_nhwindow(datawin, TRUE);
 	destroy_nhwindow(datawin);
 }
