@@ -1142,6 +1142,71 @@ register struct obj	*sobj;
 		}
 		punish(sobj);
 		break;
+#ifdef JPEXTENSION
+	case SCR_DESTROY_WEAPON:
+	    otmp = uwep;
+	    if(confused) {
+		if(!otmp) {
+		    strange_feeling(sobj,"ॺॺ롥");
+		    exercise(A_STR, FALSE);
+		    exercise(A_CON, FALSE);
+		    return(1);
+		}
+		otmp->oerodeproof = sobj->cursed;
+		p_glow2(otmp,purple);
+		break;
+	    }
+	    
+	    if(!otmp){
+		pline("%sॺॺ", body_part(HAND));
+	    }
+	    else if(!sobj->cursed || !otmp || !otmp->cursed) {
+		known = TRUE;
+		useup(otmp);
+		Your("%sϿФȤʤäƤޤä", xname(otmp));
+	    }
+	    
+	    break;
+	case SCR_CREATE_CREATE_SCROLL:
+	    pline("­˴ʪǡи");
+	    known = FALSE;
+	    otmp = mksobj_at(SCR_CREATE_CREATE_SCROLL, u.ux, u.uy, FALSE);
+	    otmp->cursed = sobj->cursed;
+
+	    break;
+	case SCR_CREATE_ALTAR:
+	    if(levl[u.ux][u.uy].typ != ROOM)
+		break;
+
+	    pline("줬ΩΤܤŤи");
+	    known = TRUE;
+	    levl[u.ux][u.uy].typ = ALTAR;
+	    levl[u.ux][u.uy].altarmask = Align2amask(A_NONE);
+	    newsym(u.ux, u.uy);
+	    break;
+	case SCR_CREATE_SINK:
+	    if(levl[u.ux][u.uy].typ != ROOM)
+		break;
+
+	    pline("줬ΩΤܤή椬и");
+	    known = TRUE;
+	    levl[u.ux][u.uy].typ = SINK;
+	    newsym(u.ux, u.uy);
+	    break;
+	case SCR_CREATE_TRAP:
+	    if(levl[u.ux][u.uy].typ != ROOM)
+		break;
+
+	    pline("줬ΩΤܤä");
+	    known = FALSE;
+	    maketrap(u.ux, u.uy, rn2(TRAPNUM) + NO_TRAP + 1);
+	    break;
+	case SCR_SYMMETRY:
+	    You("ä褦ʵ");
+	    known = TRUE;
+	    make_totter(Totter + rnd(500), FALSE);
+	    break;
+#endif
 	default:
 		impossible("What weird effect is this? (%u)", sobj->otyp);
 	}
