@@ -23,7 +23,9 @@ static void FDECL(mkshobj_at, (const struct shclass *,int,int));
 static void FDECL(nameshk, (struct monst *,const char **));
 static int  FDECL(shkinit, (const struct shclass *,struct mkroom *));
 
+#undef JPDEBUG
 static const char *shkliquors[] = {
+#ifndef JPDEBUG
     /* Ukraine */
     "Njezjin", "Tsjernigof", "Gomel", "Ossipewsk", "Gorlowka",
     /* N. Russia */
@@ -35,12 +37,14 @@ static const char *shkliquors[] = {
     /* Schweiz */
     "Leuk", "Brig", "Brienz", "Thun", "Sarnen", "Burglen", "Elm",
     "Flims", "Vals", "Schuls", "Zum Loch",
+#endif
 /*JP*/
-    "Hamada",
+    "", "_Ӹ",
     0
 };
 
 static const char *shkbooks[] = {
+#ifndef JPDEBUG
     /* Eire */
     "Skibbereen", "Kanturk", "Rath Luirc", "Ennistymon", "Lahinch",
     "Kinnegad", "Lugnaquillia", "Enniscorthy", "Gweebarra",
@@ -48,12 +52,14 @@ static const char *shkbooks[] = {
     "Cahersiveen", "Glenbeigh", "Kilmihil", "Kiltamagh",
     "Droichead Atha", "Inniscrone", "Clonegal", "Lisnaskea",
     "Culdaff", "Dunfanaghy", "Inishbofin", "Kesh",
+#endif
 /*JP*/
-    "Numata",
+    "", "_",
     0
 };
 
 static const char *shkarmors[] = {
+#ifndef JPDEBUG
     /* Turquie */
     "Demirci", "Kalecik", "Boyabai", "Yildizeli", "Gaziantep",
     "Siirt", "Akhalataki", "Tirebolu", "Aksaray", "Ermenak",
@@ -61,12 +67,14 @@ static const char *shkarmors[] = {
     "Bayburt", "Ayancik", "Zonguldak", "Balya", "Tefenni",
     "Artvin", "Kars", "Makharadze", "Malazgirt", "Midyat",
     "Birecik", "Kirikkale", "Alaca", "Polatli", "Nallihan",
+#endif
 /*JP*/
-    "Fujieda",
+    "ƣ", "_",
     0
 };
 
 static const char *shkwands[] = {
+#ifndef JPDEBUG
     /* Wales */
     "Yr Wyddgrug", "Trallwng", "Mallwyd", "Pontarfynach",
     "Rhaeader", "Llandrindod", "Llanfair-ym-muallt",
@@ -77,12 +85,14 @@ static const char *shkwands[] = {
     "Kerloch", "Beinn a Ghlo", "Drumnadrochit", "Morven",
     "Uist", "Storr", "Sgurr na Ciche", "Cannich", "Gairloch",
     "Kyleakin", "Dunvegan",
+#endif
 /*JP*/
-    "Miyashita",
+    "ܲ", "_",
     0
 };
 
 static const char *shkrings[] = {
+#ifndef JPDEBUG
     /* Hollandse familienamen */
     "Feyfer", "Flugi", "Gheel", "Havic", "Haynin", "Hoboken",
     "Imbyze", "Juyn", "Kinsky", "Massis", "Matray", "Moy",
@@ -92,12 +102,14 @@ static const char *shkrings[] = {
     "Rastegaisa", "Varjag Njarga", "Kautekeino", "Abisko",
     "Enontekis", "Rovaniemi", "Avasaksa", "Haparanda",
     "Lulea", "Gellivare", "Oeloe", "Kajaani", "Fauske",
+#endif
 /*JP*/
-    "Koba",
+    "ž", "_ð",
     0
 };
 
 static const char *shkfoods[] = {
+#ifndef JPDEBUG
     /* Indonesia */
     "Djasinga", "Tjibarusa", "Tjiwidej", "Pengalengan",
     "Bandjar", "Parbalingga", "Bojolali", "Sarangan",
@@ -106,12 +118,14 @@ static const char *shkfoods[] = {
     "Trenggalek", "Karangkobar", "Njalindoeng", "Pasawahan",
     "Pameunpeuk", "Patjitan", "Kediri", "Pemboeang", "Tringanoe",
     "Makin", "Tipor", "Semai", "Berhala", "Tegal", "Samoe",
+#endif
 /*JP*/
-    "Maeda",
+    "", "_",
     0
 };
 
 static const char *shkweapons[] = {
+#ifndef JPDEBUG
     /* Perigord */
     "Voulgezac", "Rouffiac", "Lerignac", "Touverac", "Guizengeard",
     "Melac", "Neuvicq", "Vanzac", "Picq", "Urignac", "Corignac",
@@ -119,12 +133,14 @@ static const char *shkweapons[] = {
     "Cazelon", "Eypau", "Carignan", "Monbazillac", "Jonzac",
     "Pons", "Jumilhac", "Fenouilledes", "Laguiolet", "Saujon",
     "Eymoutiers", "Eygurande", "Eauze", "Labouheyre",
+#endif
 /*JP*/
-    "Kasahara",
+    "޸", "_",
     0
 };
 
 static const char *shktools[] = {
+#ifndef JPDEBUG
     /* Spmi */
     "Ymla", "Eed-morra", "Cubask", "Nieb", "Bnowr Falr", "Telloc Cyaj",
     "Sperc", "Noskcirdneh", "Yawolloh", "Hyeghu", "Niskal", "Trahnil",
@@ -149,12 +165,14 @@ static const char *shktools[] = {
 #ifdef VMS
     "Lez-tneg", "Ytnu-haled", "Niknar",
 #endif
+#endif
 /*JP*/
-    "Awatsu",
+    "", "_",
     0
 };
 
 static const char *shklight[] = {
+#ifndef JPDEBUG
     /* Romania */
     "Zarnesti", "Slanic", "Nehoiasu", "Ludus", "Sighisoara", "Nisipitu",
     "Razboieni", "Bicaz", "Dorohoi", "Vaslui", "Fetesti", "Tirgu Neamt",
@@ -163,12 +181,14 @@ static const char *shklight[] = {
     "Silistra", "Tulovo", "Panagyuritshte", "Smolyan", "Kirklareli",
     "Pernik", "Lom", "Haskovo", "Dobrinishte", "Varvara", "Oryahovo",
     "Troyan", "Lovech", "Sliven",
+#endif
 /*JP*/
-    "Shiraishi",
+    "", "_ɹ",
     0
 };
 
 static const char *shkgeneral[] = {
+#ifndef JPDEBUG
     /* Suriname */
     "Hebiwerie", "Possogroenoe", "Asidonhopo", "Manlobbi",
     "Adjama", "Pakka Pakka", "Kabalebo", "Wonotobo",
@@ -183,8 +203,9 @@ static const char *shkgeneral[] = {
     /* Iceland */
     "Akureyri", "Kopasker", "Budereyri", "Akranes", "Bordeyri",
     "Holmavik",
+#endif
 /*JP*/
-    "Kunedog",
+    "Kunedog", "_",
     0
 };
 
@@ -303,7 +324,7 @@ nameshk(shk, nlp)
 struct monst *shk;
 const char *nlp[];
 {
-	int i, trycnt, names_avail;
+        int /*i, */trycnt, names_avail;
 	const char *shname = 0;
 	struct monst *mtmp;
 	int name_wanted;
@@ -315,6 +336,32 @@ const char *nlp[];
 	    shname = "Izchak";
 	    shk->female = FALSE;
 	} else {
+#if 1	/* JP */
+	     /* We decide to use simple way */
+	    for (names_avail = 0; nlp[names_avail]; names_avail++)
+		 ;
+
+	    for (trycnt = 0; trycnt < 50; trycnt++) {
+		 name_wanted = rn2(names_avail);
+		 shk->female = name_wanted & 1;
+		 shname = nlp[name_wanted];
+		 if(shname[0] & 0x80){
+		      shk->female = 0;
+		 }
+		 else if(shname[0] == '_'){
+		      ++shname;
+		      shk->female = 1;
+		 }
+		 for (mtmp = fmon; mtmp; mtmp = mtmp->nmon) {
+		      if (mtmp == shk) continue;
+		      if (!mtmp->isshk) continue;
+		      if (strcmp(ESHK(mtmp)->shknam, shname)) continue;
+		      break;
+		 }
+		 if(!mtmp)
+		      break;
+	    }
+#else
 	    /* We want variation from game to game, without needing the save
 	       and restore support which would be necessary for randomization;
 	       try not to make too many assumptions about time_t's internals;
@@ -356,6 +403,7 @@ const char *nlp[];
 		}
 		if (!mtmp) break;	/* new name */
 	    }
+#endif
 	}
 	(void) strncpy(ESHK(shk)->shknam, shname, PL_NSIZ);
 	ESHK(shk)->shknam[PL_NSIZ-1] = 0;
