@@ -172,6 +172,7 @@ nh_timeout()
 	    if((upp->p_flgs & TIMEOUT) && !(--upp->p_flgs & TIMEOUT)) {
 		switch(upp - u.uprops){
 		case STONED:
+			killer = NULL;	/* for JP */
 			if (!killer) {
 				killer_format = KILLED_BY_AN;
 /*JP				killer = "cockatrice";*/
@@ -248,6 +249,13 @@ nh_timeout()
 			heal_legs();
 			stop_occupation();
 			break;
+#ifdef JPEXTENSION
+		case TOTTER:
+		    	Totter = 0;
+			make_totter(0L, TRUE);
+			stop_occupation();
+			break;
+#endif
 		case HALLUC:
 			HHallucination = 1;
 			make_hallucinated(0L, TRUE, 0L);
@@ -468,7 +476,7 @@ long timeout;
 			pline("ϡ%s٤ĤƤ褦",
 			    flags.female ? "ޥ" : "ѥ");
 		    } else if (mon->data->mlet == S_DRAGON) {
-/*JP			verbalize("Gleep!");		/* Mything eggs :-) */
+/*JP			verbalize("Gleep!");*/		/* Mything eggs :-) */
 			verbalize("֥");		/* Mything eggs :-) */
 		    }
 		    break;
