@@ -9,6 +9,11 @@
 **	JNetHack may be freely redistributed.  See license for details. 
 */
 
+/*
+	Y2K problem fixed
+	by Issei Numata		1 Nov, 1999	
+ */
+
 #include "hack.h"
 #include "dlb.h"
 #ifdef SHORT_FILENAMES
@@ -17,12 +22,8 @@
 #include "patchlevel.h"
 #endif
 
-#ifdef REPORTSCORE	/* jp */
-#include "patchlevel.h"
-#include "../japanese/jpatchlevel.h"
-#include <sys/utsname.h>
-
-extern int report_flag;	/* end.c  */
+#ifdef NH_EXTENSION_REPORT	/* jp */
+extern int report_flag;		/* end.c  */
 #endif
 
 #ifdef VMS
@@ -63,7 +64,16 @@ struct toptenentry {
 	int deathdnum, deathlev;
 	int maxlvl, hp, maxhp, deaths;
 	int ver_major, ver_minor, patchlevel;
+#if 0
 	char deathdate[8], birthdate[8]; /* see readentry about size */
+#endif
+/*
+  Y2K problem fixed
+
+  now yymmdd returned 8 degits format like as '20000101'
+  so we need more date storage size	(by issei 1 Nov 1999)
+ */
+	char deathdate[16], birthdate[16]; /* see readentry about size */
 	int uid;
 	char plchar;
 	char sex;
@@ -110,20 +120,20 @@ static void
 topten_print(x)
 const char *x;
 {
-	if (toptenwin == WIN_ERR)
-	    raw_print(x);
-	else
-	    putstr(toptenwin, ATR_NONE, x);
+     if (toptenwin == WIN_ERR)
+	  raw_print(x);
+     else
+	  putstr(toptenwin, ATR_NONE, x);
 }
 
 static void
 topten_print_bold(x)
 const char *x;
 {
-	if (toptenwin == WIN_ERR)
-	    raw_print_bold(x);
-	else
-	    putstr(toptenwin, ATR_BOLD, x);
+     if (toptenwin == WIN_ERR)
+	  raw_print_bold(x);
+     else
+	  putstr(toptenwin, ATR_BOLD, x);
 }
 
 static xchar
@@ -149,11 +159,24 @@ readentry(rfile,tt)
 FILE *rfile;
 struct toptenentry *tt;
 {
+/*
+  Y2K problem fixed
+
+  now yymmdd returned long year format like as '20000101'
+  so we need more date storage size	(by issei 1 Nov 1999)
+
 #ifdef NO_SCAN_BRACK
 	static char *fmt = "%d %d %d %ld %d %d %d %d %d %d %6s %6s %d%*c%c%c %s %s%*c";
 #else
 	static char *fmt = "%d.%d.%d %ld %d %d %d %d %d %d %6s %6s %d %c%c %[^,],%[^\n]%*c";
 #endif
+ */
+#ifdef NO_SCAN_BRACK
+	static char *fmt = "%d %d %d %ld %d %d %d %d %d %d %s %s %d%*c%c%c %s %s%*c";
+#else
+	static char *fmt = "%d.%d.%d %ld %d %d %d %d %d %d %s %s %d %c%c %[^,],%[^\n]%*c";
+#endif
+
 
 #ifdef __BEOS__
 	/*
@@ -175,7 +198,11 @@ struct toptenentry *tt;
 		tested_scanf_bug  = TRUE;
 		(void) sscanf("123456 789012", "%6s %6s", s1, s2);
 		if (strcmp(s2, "789012") != 0)
+/*
+  Y2K problem fixed
 			fmt = "%d.%d.%d %ld %d %d %d %d %d %d %7s %7s %d %c%c %[^,],%[^\n]%*c";
+  */
+			fmt = "%d.%d.%d %ld %d %d %d %d %d %d %s %s %d %c%c %[^,],%[^\n]%*c";
 	}
 #endif /* __BEOS__ */ 
 
@@ -190,9 +217,10 @@ struct toptenentry *tt;
 			&tt->maxlvl, &tt->hp, &tt->maxhp, &tt->deaths,
 			tt->deathdate, tt->birthdate,
 			&tt->uid, &tt->plchar, &tt->sex,
-			tt->name, tt->death) != TTFIELDS)
+		        tt->name, tt->death) != TTFIELDS){
 #undef TTFIELDS
 		tt->points = 0;
+	}
 	else {
 #ifdef NO_SCAN_BRACK
 		if(tt->points > 0) {
@@ -200,6 +228,14 @@ struct toptenentry *tt;
 			nsb_unmung_line(tt->death);
 		}
 #endif
+/*
+  Y2K problem fixed
+ */
+		if(atoi(tt->deathdate) < 1900)	/* OLD format */
+		    Sprintf(tt->deathdate, "%08d", atoi(tt->deathdate) + 1900);
+
+		if(atoi(tt->birthdate) < 1900)	/* OLD format */
+		    Sprintf(tt->birthdate, "%08d", atoi(tt->birthdate) + 1900);
 	}
 }
 
@@ -709,70 +745,12 @@ boolean re;
 
 	hppos = COLNO - (sizeof("  Hp [max]")-1); /* sizeof(str) includes \0 */
 
-#ifdef REPORTSCORE
+#ifdef NH_EXTENSION_REPORT
 	if(report_flag && re){
-	  struct utsname nm;
-	  FILE *report;
-	  int sd;
-
-	  sd = connect_scoreserver(SCORE_TIMEOUT);
-	  if(sd < 0){
-	      raw_printf("Report: %s", remote_err());
-	  }
-	  else{
-	    report = fdopen(sd, "w+");
-	    fprintf(report, "PUT SCORE\r\n");
-	    fflush(report);
-
-	    if(soc_wait(sd) != 335)
-	      goto report_done;
-
-	    uname(&nm);
-	    fprintf(report, "version: %d\r\n", REPORTSCORE_VER);
-
-	    fprintf(report, "sysname: %s\r\n", nm.sysname);
-	    fprintf(report, "release: %s\r\n", nm.release);
-	    fprintf(report, "machine: %s\r\n", nm.machine);
-
-	    fprintf(report, "nethack version: %d %d %d %d\r\n", 
-		    VERSION_MAJOR, VERSION_MINOR,
-		    PATCHLEVEL, EDITLEVEL);
-	    fprintf(report, "jnethack version: %d %d %d %d\r\n", 
-		    JVERSION_MAJOR, JVERSION_MINOR,
-		    JPATCHLEVEL, JEDITLEVEL);
-	    fprintf(report, "character: %s\r\n",
-		    jtrns_mon(pl_character, flags.female));
-	    fprintf(report, "female: %d\r\n", flags.female);
-	    fprintf(report, "name: %s\r\n", plname);
-	    fprintf(report, "score: %d\r\n", u.urexp);
-	    fprintf(report, "action: %s\r\n", action);
-	    fprintf(report, "uz: %d\r\n", depth(&u.uz));
-	    fprintf(report, "level: %d\r\n", u.ulevel);
-	    fprintf(report, "maxhp: %d\r\n", u.uhpmax);
-	    fprintf(report, "deepest: %d\r\n", deepest_lev_reached(TRUE));
-	    fprintf(report, "gold: %d\r\n", u.ugold);
-	    fprintf(report, "moves: %d\r\n", moves);
-	    fprintf(report, "dying message: %s\r\n", linebuf);
-/*	    fprintf(report, "email: %s\r\n", get_email());*/
-	    fprintf(report, "homeurl: %s\r\n", get_homeurl());
-	    fprintf(report, ".\r\n");
-	    fflush(report);
-
-	    if(soc_wait(sd) != 250)
-	      goto report_done;
-
-	  report_done:
-	    fprintf(report, "QUIT\r\n");
-	    fflush(report);
-
-	    soc_wait(sd);
-
-	    fclose(report);
-	    close(sd);
-	  }
+	    report_score(action, linebuf);
+	    send_bones();
 	}
 #endif
-
 	while(lngr >= hppos ){
 /*
 **	hpposŬʰ֤ʬ䤹롥
@@ -1113,4 +1091,13 @@ nsb_unmung_line(p)
 }
 #endif /* NO_SCAN_BRACK */
 
+#ifdef GTK_GRAPHICS
+winid
+create_toptenwin()
+{
+    toptenwin = create_nhwindow(NHW_TEXT);
+
+    return toptenwin;
+}
+#endif
 /*topten.c*/
