@@ -317,7 +317,7 @@ boolean td;	/* td == TRUE : trapdoor or hole */
 	    dont_fall = "ʤϥڥåȤˤäưäѤ줿";
 	}
 	if (dont_fall) {
-/*JP	    You(dont_fall);*.
+/*JP	    You(dont_fall);*/
 	    pline(dont_fall);
 	    /* hero didn't fall through, but any objects here might */
 	    impact_drop((struct obj *)0, u.ux, u.uy, 0);
@@ -834,7 +834,7 @@ two_hand:		    erode_weapon(FALSE);
 		    locomotion(uasmon, "Ƨ߹"), ""));
 		if(Antimagic) {
 		    shieldeff(u.ux, u.uy);
-/*JP		    You_feel("momentarily different.");(/
+/*JP		    You_feel("momentarily different.");(*/
 		    You("̵ϴ򴶤");
 		    /* Trap did nothing; don't remove it --KAA */
 		} else {
@@ -2156,13 +2156,14 @@ drown()
 			if (flags.verbose)
 /*JP				pline("But you aren't drowning.");*/
 				pline("ʤŮʤä");
-			if (!Is_waterlevel(&u.uz))
+			if (!Is_waterlevel(&u.uz)){
 				if (Hallucination)
 /*JP					Your("keel hits the bottom.");*/
 					You("˥ˡɥåפ᤿");
 				else
 /*JP					You("touch bottom.");*/
 					You("ˤĤ");
+			}
 		}
 		if (Punished) {
 			unplacebc();
@@ -2176,7 +2177,7 @@ drown()
 	}
 	if((Teleportation || can_teleport(uasmon)) &&
 	   (Teleport_control || rn2(3) < Luck+2)) {
-/*JP		You("attempt a teleport spell.");	/* utcsri!carroll */
+/*JP		You("attempt a teleport spell.");*/	/* utcsri!carroll */
 		You("ְִưˡ򾧤褦Ȥ");	/* utcsri!carroll */
 		(void) dotele();
 		if(!is_pool(u.ux,u.uy))
@@ -2500,7 +2501,7 @@ struct trap *ttmp;
 	    useup(obj);	/* oil */
 	    makeknown(POT_OIL);
 	}
-/*JP	You("repair the squeaky board.");	/* no madeby_u */
+/*JP	You("repair the squeaky board.");*/	/* no madeby_u */
 	You("Ĥ");	/* no madeby_u */
 	deltrap(ttmp);
 	newsym(u.ux + u.dx, u.uy + u.dy);
