@@ -209,7 +209,7 @@ register struct monst *mtmp;
 
 	if(unweapon) {
 	    unweapon=FALSE;
-	    if(flags.verbose)
+	    if(flags.verbose){
 		if(uwep)
 /*JP		    You("begin bashing monsters with your %s.",
 			aobjnam(uwep, (char *)0));*/
@@ -223,6 +223,7 @@ register struct monst *mtmp;
 #endif /*JP*/
 		    You("%sǲʪʤĤ",
 			uarmg ? "" : "Ǽ");
+	    }
 	}
 	exercise(A_STR, TRUE);		/* you're exercising muscles */
 	/* andrew@orca: prevent unlimited pick-axe attacks */
@@ -556,11 +557,12 @@ register int thrown;
 			/* egg is always either used up or transformed, so next
 			   hand-to-hand attack should yield a "bashing" mesg */
 			if (obj == uwep) unweapon = TRUE;
-			if (obj->spe && obj->corpsenm >= LOW_PM)
+			if (obj->spe && obj->corpsenm >= LOW_PM){
 			    if (obj->quan < 5)
 				change_luck((schar) -(obj->quan));
 			    else
 				change_luck(-5);
+			}
 
 			if (obj->corpsenm == PM_COCKATRICE) {
 			    learn_egg_type(PM_COCKATRICE);
@@ -1704,7 +1706,7 @@ use_weapon:
 /*JP			    Your("hug passes harmlessly through %s.",*/
 			    You("%s򱩸򤤹ʤˤ褦ȤԤ",
 				mon_nam(mon));
-			else if (!sticks(mon->data) && !u.uswallow)
+			else if (!sticks(mon->data) && !u.uswallow){
 			    if (mon==u.ustuck) {
 /*JP				pline("%s is being %s.", Monnam(mon),
 				    u.umonnum==PM_ROPE_GOLEM ? "choked":
@@ -1719,6 +1721,7 @@ use_weapon:
 				u.ustuck = mon;
 				sum[i] = damageum(mon, mattk);
 			    }
+			}
 			break;
 
 		case AT_EXPL:	/* automatic hit if next to */
@@ -1841,12 +1844,13 @@ boolean kicked;
 	      }
 	    break;
 	  case AD_RUST:
-	    if(mhit && !mon->mcan)
-	      if (kicked) {
-		if (uarmf)
-		    (void) rust_dmg(uarmf, xname(uarmf), 1, TRUE);
-	      } else
-		erode_weapon(FALSE);
+	      if(mhit && !mon->mcan){
+		  if (kicked) {
+		      if (uarmf)
+			  (void) rust_dmg(uarmf, xname(uarmf), 1, TRUE);
+		  } else
+		      erode_weapon(FALSE);
+	      }
 	    break;
 	  case AD_MAGM:
 	    /* wrath of gods for attacking Oracle */
