@@ -509,7 +509,7 @@ register struct monst *grd;
 		return(0);
 	    }
 
-	    if (!u_in_vault)
+	    if (!u_in_vault){
 		if (u_carry_gold) {	/* player teleported */
 		    m = grd->mx;
 		    n = grd->my;
@@ -536,6 +536,7 @@ letknow:
 		    egrd->gddone = 1;
 		    goto cleanup;
 		}
+	    }
 	}
 
 	if(egrd->fcend > 1) {
