@@ -184,10 +184,11 @@ register struct obj *otmp;
 		}
 		break;
 	case WAN_SPEED_MONSTER:
-		if (!resist(mtmp, otmp->oclass, 0, NOTELL))
+	    if (!resist(mtmp, otmp->oclass, 0, NOTELL)){
 			if (mtmp->mspeed == MSLOW) mtmp->mspeed = 0;
 			else mtmp->mspeed = MFAST;
-		break;
+	    }
+	    break;
 	case WAN_UNDEAD_TURNING:
 	case SPE_TURN_UNDEAD:
 		wake = FALSE;
@@ -624,7 +625,7 @@ register struct obj *obj;
 				flags.botl = 1;
 			}
 			break;
-		/* case RIN_PROTECTION: /* not needed */
+		/* case RIN_PROTECTION:*/ /* not needed */
 	}
 	if (objects[obj->otyp].oc_magic
 	    || (obj->spe && (obj->oclass == ARMOR_CLASS ||
@@ -738,12 +739,13 @@ polyuse(objhdr, mat, minwt)
 	if (((int) objects[otmp->otyp].oc_material == mat) ==
 		(rn2(minwt + 1) != 0)) {
 	    /* appropriately add damage to bill */
-	    if (costly_spot(otmp->ox, otmp->oy))
+	    if (costly_spot(otmp->ox, otmp->oy)){
 		if (*u.ushops)
 			addtobill(otmp, FALSE, FALSE, FALSE);
 		else
 			(void)stolen_value(otmp,
 					   otmp->ox, otmp->oy, FALSE, FALSE);
+	    }
 	    minwt -= (int)otmp->quan;
 	    delobj(otmp);
 	}
@@ -849,12 +851,13 @@ struct obj *obj;
 		(void) splitobj(obj, (long)rnd((int)obj->quan - 1));
 
 	/* appropriately add damage to bill */
-	if (costly_spot(obj->ox, obj->oy))
+	if (costly_spot(obj->ox, obj->oy)){
 		if (*u.ushops)
 			addtobill(obj, FALSE, FALSE, FALSE);
 		else
 			(void)stolen_value(obj,
 					   obj->ox, obj->oy, FALSE, FALSE);
+	}
 
 	/* zap the object */
 	delobj(obj);
@@ -2954,9 +2957,9 @@ destroy_item(osym, dmgtyp)
 register int osym, dmgtyp;
 {
 	register struct obj *obj, *obj2;
-	register int dmg, xresist, skip;
-	register long i, cnt, quan;
-	register int dindx;
+	register int dmg=0, xresist, skip;
+	register long i, cnt, quan=0;
+	register int dindx=0;
 	const char *mult;
 
 	for(obj = invent; obj; obj = obj2) {
