@@ -593,14 +593,14 @@ char ch2;
 	int i;
 	char attribute;
 
-	i = flags.grmode ? attrib_gr_normal
+	i = iflags.grmode ? attrib_gr_normal
 			 : attrib_text_normal;
 
 	attribute = (char)((g_attribute == 0) ? i : g_attribute);
-	if (!flags.grmode) {
+	if (!iflags.grmode) {
 		txt_xputc2(ch, ch2, attribute);
 #  ifdef SCREEN_VGA
-	} else if (flags.usevga) {
+	} else if (iflags.usevga) {
 		vga_xputc2(ch, ch2, attribute);
 #  endif /*SCREEN_VGA*/
 	}
