@@ -270,7 +270,7 @@ XColor   *color;	/* the X color structure; changed only if successful */
     long	cdiff = 16777216; /* 2^24; hopefully our map is smaller */
     XColor	tmp;
     static	XColor *table = 0;
-    register	i, j;
+    register int i, j;
     register long tdiff;
 
     /* if the screen doesn't have a big colormap, don't waste our time */
@@ -967,6 +967,8 @@ static XtResource resources[] = {
       XtOffset(AppResources *, radar), XtRString, "True" },
 #endif
 #endif
+    { "centerPopups", "CenterPopups", XtRBoolean, sizeof(Boolean),
+      XtOffset(AppResources *,center_popups), XtRImmediate, False },
 };
 
 void
