@@ -355,6 +355,9 @@ create_text_window(wp)
 
     text_info->extra_width  = left_margin + right_margin;
     text_info->extra_height = top_margin + bottom_margin;
+
+    /* Send events to "text" which is where the translations are. */
+    XtSetKeyboardFocus (form, wp->w);
 }
 
 void
@@ -654,7 +657,7 @@ rip_exposed(w, client_data, widget_data)
 		x-width/2, y, rip_line[i], len);
 #else
 	XFontSet fontset = WindowFontSet(w);
-	XFontSetExtents *extent = XExtentsOfFontSet(fontset);
+/*	XFontSetExtents *extent = XExtentsOfFontSet(fontset);*/
 	int width = XmbTextEscapement(fontset, rip_line[i], len);
 	XmbDrawString(dpy, XtWindow(w), fontset, gc,
 		x-width/2, y, rip_line[i], len);
